Rucio - Scientific Data Management (Core Package)
=================================================

Rucio is a software framework that provides functionality to organize, manage, and access large volumes of scientific data using customisable policies. The data can be spread across globally distributed locations and across heterogeneous data centers, uniting different storage and network technologies as a single federated entity. Rucio offers advanced features such as distributed data recovery or adaptive replication, and is highly scalable, modular, and extensible. Rucio has been originally developed to meet the requirements of the high-energy physics experiment ATLAS, and is continuously extended to support LHC experiments and other diverse scientific communities.


Documentation
-------------

General information and latest documentation about Rucio can be found at `readthedocs <https://rucio.readthedocs.io>`_ or our `webpage <https://rucio.cern.ch>`_.

Developers
----------

For information on how to contribute to Rucio, please refer and follow our `CONTRIBUTING <CONTRIBUTING.rst>`_ guidelines.

Operators
----------

To learn how to deploy and configure Rucio, consult the `documentation <http://rucio.readthedocs.io/#operator-documentation>`_ available online.

Getting Support
----------------

If you are looking for support, join us on our Slack `support <https://rucio.slack.com/messages/#support>`_ channel, or send an email to our public mailing list `rucio-users@googlegroups.com <mailto:rucio-users@googlegroups.com>`_.
